import 'package:flutter/cupertino.dart';
import 'package:jpush_flutter/jpush_flutter.dart';

import 'events.dart';

class JPushUtil {
  static final JPush jpush = JPush();

  static bool jPushInitEd = false;

  static initPlatformState(String appKey, String channelName) async {
    if (jPushInitEd) return;

    jpush.addEventHandler(
      onReceiveNotification: (Map<String, dynamic> message) async {
        debugPrint("flutter onReceiveNotification: $message");
      },
      onOpenNotification: (Map<String, dynamic> message) async {
        debugPrint("flutter onOpenNotification: $message");
      },
      onReceiveMessage: (Map<String, dynamic> message) async {
        debugPrint("flutter onReceiveMessage: $message");
        eventBus.fire(JPushReceiveMessage(message));
      },
      onReceiveNotificationAuthorization: (Map<String, dynamic> message) async {
        debugPrint("flutter onReceiveNotificationAuthorization: $message");
      },
      onNotifyMessageUnShow: (Map<String, dynamic> message) async {
        debugPrint("flutter onNotifyMessageUnShow: $message");
      },
    );

    jpush.setAuth(enable: true);
    jpush.setup(
      appKey: appKey, //你自己应用的 AppKey
      channel: channelName,
      production: false,
      debug: true,
    );
    jpush.applyPushAuthority(const NotificationSettingsIOS(sound: true, alert: true, badge: true));

    jPushInitEd = true;

    // Platform messages may fail, so we use a try/catch PlatformException.
    String rid = await jpush.getRegistrationID();
    debugPrint("flutter get registration id : $rid");

    return rid;

  }

  static checkPermission() async {
    bool open = await jpush.isNotificationEnabled();
    if (!open) {
      jpush.openSettingsForNotification();
      return Future.error('未打开通知权限');
    }
  }

  static stop() async {
    await jpush.stopPush();
  }

  static resume() async {
    await jpush.resumePush();
  }

  /// 清空通知栏上的所有通知
  static clearAllNotifications() {
    jpush.clearAllNotifications();
  }

  static setBadge(int badge) async {
    await jpush.setBadge(badge);
  }

  static setTags(String tagsStr) async {
    if (tagsStr.isEmpty) return;
    Map allTagsMap = await jpush.getAllTags();
    debugPrint('allTagsMap $allTagsMap');
    Map respMap = await jpush.setTags(tagsStr.split(','));
    return respMap;
  }

  static getAllTags() async {
    Map respMap = await jpush.getAllTags();
    return respMap;
  }
}
